gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-exchange] 02/04: cmd to del auditor


From: gnunet
Subject: [taler-exchange] 02/04: cmd to del auditor
Date: Fri, 27 Nov 2020 00:05:44 +0100

This is an automated email from the git hooks/post-receive script.

grothoff pushed a commit to branch master
in repository exchange.

commit 98f5960411077dd8be648cbd21fd495bb874f8fd
Author: Christian Grothoff <christian@grothoff.org>
AuthorDate: Thu Nov 26 22:54:33 2020 +0100

    cmd to del auditor
---
 src/include/taler_exchange_service.h               |  2 -
 src/include/taler_testing_lib.h                    |  6 +-
 src/lib/exchange_api_management_auditor_disable.c  |  1 -
 src/testing/Makefile.am                            |  1 +
 src/testing/testing_api_cmd_auditor_add.c          | 35 ++++++----
 ...auditor_add.c => testing_api_cmd_auditor_del.c} | 79 ++++++++--------------
 6 files changed, 56 insertions(+), 68 deletions(-)

diff --git a/src/include/taler_exchange_service.h 
b/src/include/taler_exchange_service.h
index 8b1feb15..8a5ba311 100644
--- a/src/include/taler_exchange_service.h
+++ b/src/include/taler_exchange_service.h
@@ -2398,7 +2398,6 @@ struct TALER_EXCHANGE_ManagementAuditorDisableHandle;
  * @param ctx the context
  * @param url HTTP base URL for the exchange
  * @param auditor_pub the public signing key of the auditor
- * @param auditor_url base URL of the auditor
  * @param validity_end when was this decided?
  * @param master_sig signature affirming the auditor addition
  * @param cb function to call with the exchange's result
@@ -2410,7 +2409,6 @@ TALER_EXCHANGE_management_disable_auditor (
   struct GNUNET_CURL_Context *ctx,
   const char *url,
   const struct TALER_AuditorPublicKeyP *auditor_pub,
-  const char *auditor_url,
   struct GNUNET_TIME_Absolute validity_end,
   const struct TALER_MasterSignatureP *master_sig,
   TALER_EXCHANGE_ManagementAuditorDisableCallback cb,
diff --git a/src/include/taler_testing_lib.h b/src/include/taler_testing_lib.h
index 61f1c50a..b89a775e 100644
--- a/src/include/taler_testing_lib.h
+++ b/src/include/taler_testing_lib.h
@@ -2041,10 +2041,14 @@ TALER_TESTING_cmd_auditor_add (const char *label,
  * "[auditor]" section in the configuration file.
  *
  * @param label command label.
+ * @param expected_http_status expected HTTP status from exchange
+ * @param bad_sig should we use a bogus signature?
  * @return the command
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_auditor_del (const char *label);
+TALER_TESTING_cmd_auditor_del (const char *label,
+                               unsigned int expected_http_status,
+                               bool bad_sig);
 
 
 /**
diff --git a/src/lib/exchange_api_management_auditor_disable.c 
b/src/lib/exchange_api_management_auditor_disable.c
index d9181870..823f9b13 100644
--- a/src/lib/exchange_api_management_auditor_disable.c
+++ b/src/lib/exchange_api_management_auditor_disable.c
@@ -128,7 +128,6 @@ TALER_EXCHANGE_management_disable_auditor (
   struct GNUNET_CURL_Context *ctx,
   const char *url,
   const struct TALER_AuditorPublicKeyP *auditor_pub,
-  const char *auditor_url,
   struct GNUNET_TIME_Absolute validity_end,
   const struct TALER_MasterSignatureP *master_sig,
   TALER_EXCHANGE_ManagementAuditorDisableCallback cb,
diff --git a/src/testing/Makefile.am b/src/testing/Makefile.am
index e1d01225..c3c5edd3 100644
--- a/src/testing/Makefile.am
+++ b/src/testing/Makefile.am
@@ -36,6 +36,7 @@ libtalertesting_la_LDFLAGS = \
   -no-undefined
 libtalertesting_la_SOURCES = \
   testing_api_cmd_auditor_add.c \
+  testing_api_cmd_auditor_del.c \
   testing_api_cmd_auditor_deposit_confirmation.c \
   testing_api_cmd_auditor_exchanges.c \
   testing_api_cmd_auditor_exec_auditor.c \
diff --git a/src/testing/testing_api_cmd_auditor_add.c 
b/src/testing/testing_api_cmd_auditor_add.c
index cfdcae15..5112d1fb 100644
--- a/src/testing/testing_api_cmd_auditor_add.c
+++ b/src/testing/testing_api_cmd_auditor_add.c
@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2018-2020 Taler Systems SA
+  Copyright (C) 2020 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 /**
  * @file testing/testing_api_cmd_auditor_add.c
  * @brief command for testing /auditor_add.
- * @author Marcello Stanisci
+ * @author Christian Grothoff
  */
 #include "platform.h"
 #include "taler_json_lib.h"
@@ -112,6 +112,18 @@ auditor_add_run (void *cls,
   now = GNUNET_TIME_absolute_get ();
   (void) GNUNET_TIME_round_abs (&now);
   ds->is = is;
+  if (GNUNET_OK !=
+      GNUNET_CONFIGURATION_get_value_filename (is->cfg,
+                                               "auditor",
+                                               "BASE_URL",
+                                               &auditor_url))
+  {
+    GNUNET_log_config_missing (GNUNET_ERROR_TYPE_ERROR,
+                               "auditor",
+                               "BASE_URL");
+    TALER_TESTING_interpreter_next (ds->is);
+    return;
+  }
   if (ds->bad_sig)
   {
     memset (&master_sig,
@@ -134,6 +146,7 @@ auditor_add_run (void *cls,
                                  "exchange-offline",
                                  "MASTER_PRIV_FILE");
       TALER_TESTING_interpreter_next (ds->is);
+      GNUNET_free (auditor_url);
       return;
     }
     if (GNUNET_SYSERR ==
@@ -144,6 +157,7 @@ auditor_add_run (void *cls,
                   fn);
       GNUNET_free (fn);
       TALER_TESTING_interpreter_next (ds->is);
+      GNUNET_free (auditor_url);
       return;
     }
     if (GNUNET_OK !=
@@ -156,11 +170,11 @@ auditor_add_run (void *cls,
                   fn);
       GNUNET_free (fn);
       TALER_TESTING_interpreter_next (ds->is);
+      GNUNET_free (auditor_url);
       return;
     }
     GNUNET_free (fn);
 
-
     if (GNUNET_OK !=
         GNUNET_CONFIGURATION_get_value_filename (is->cfg,
                                                  "auditor",
@@ -171,6 +185,7 @@ auditor_add_run (void *cls,
                                  "auditor",
                                  "AUDITOR_PRIV_FILE");
       TALER_TESTING_interpreter_next (ds->is);
+      GNUNET_free (auditor_url);
       return;
     }
     if (GNUNET_SYSERR ==
@@ -181,6 +196,7 @@ auditor_add_run (void *cls,
                   fn);
       GNUNET_free (fn);
       TALER_TESTING_interpreter_next (ds->is);
+      GNUNET_free (auditor_url);
       return;
     }
     if (GNUNET_OK !=
@@ -193,6 +209,7 @@ auditor_add_run (void *cls,
                   fn);
       GNUNET_free (fn);
       TALER_TESTING_interpreter_next (ds->is);
+      GNUNET_free (auditor_url);
       return;
     }
     GNUNET_free (fn);
@@ -217,18 +234,6 @@ auditor_add_run (void *cls,
                                 &master_sig.eddsa_signature);
     }
   }
-  if (GNUNET_OK !=
-      GNUNET_CONFIGURATION_get_value_filename (is->cfg,
-                                               "auditor",
-                                               "BASE_URL",
-                                               &auditor_url))
-  {
-    GNUNET_log_config_missing (GNUNET_ERROR_TYPE_ERROR,
-                               "auditor",
-                               "BASE_URL");
-    TALER_TESTING_interpreter_next (ds->is);
-    return;
-  }
   if (GNUNET_OK !=
       GNUNET_CONFIGURATION_get_value_string (is->cfg,
                                              "exchange",
diff --git a/src/testing/testing_api_cmd_auditor_add.c 
b/src/testing/testing_api_cmd_auditor_del.c
similarity index 79%
copy from src/testing/testing_api_cmd_auditor_add.c
copy to src/testing/testing_api_cmd_auditor_del.c
index cfdcae15..d6685884 100644
--- a/src/testing/testing_api_cmd_auditor_add.c
+++ b/src/testing/testing_api_cmd_auditor_del.c
@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2018-2020 Taler Systems SA
+  Copyright (C) 2020 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -17,9 +17,9 @@
   <http://www.gnu.org/licenses/>
 */
 /**
  * @file testing/testing_api_cmd_auditor_add.c
  * @brief command for testing /auditor_add.
  * @author Marcello Stanisci
  */
 #include "platform.h"
 #include "taler_json_lib.h"
@@ -30,15 +30,15 @@
 
 
 /**
  * State for a "auditor_add" CMD.
  */
-struct AuditorAddState
+struct AuditorDelState
 {
 
   /**
    * Auditor enable handle while operation is running.
    */
-  struct TALER_EXCHANGE_ManagementAuditorEnableHandle *dh;
+  struct TALER_EXCHANGE_ManagementAuditorDisableHandle *dh;
 
   /**
    * Our interpreter.
@@ -65,10 +65,10 @@ struct AuditorAddState
  * @param hr HTTP response details
  */
 static void
-auditor_add_cb (void *cls,
+auditor_del_cb (void *cls,
                 const struct TALER_EXCHANGE_HttpResponse *hr)
 {
-  struct AuditorAddState *ds = cls;
+  struct AuditorDelState *ds = cls;
 
   ds->dh = NULL;
   if (ds->expected_response_code != hr->http_status)
@@ -97,13 +97,12 @@ auditor_add_cb (void *cls,
  * @param is the interpreter state.
  */
 static void
-auditor_add_run (void *cls,
+auditor_del_run (void *cls,
                  const struct TALER_TESTING_Command *cmd,
                  struct TALER_TESTING_Interpreter *is)
 {
-  struct AuditorAddState *ds = cls;
+  struct AuditorDelState *ds = cls;
   struct TALER_AuditorPublicKeyP auditor_pub;
-  char *auditor_url;
   char *exchange_url;
   struct TALER_MasterSignatureP master_sig;
   struct GNUNET_TIME_Absolute now;
@@ -201,34 +200,19 @@ auditor_add_run (void *cls,
 
     /* now sign */
     {
-      struct TALER_ExchangeAddAuditorPS kv = {
-        .purpose.purpose = htonl (TALER_SIGNATURE_MASTER_ADD_AUDITOR),
+      struct TALER_ExchangeDelAuditorPS kv = {
+        .purpose.purpose = htonl (TALER_SIGNATURE_MASTER_DEL_AUDITOR),
         .purpose.size = htonl (sizeof (kv)),
-        .start_date = GNUNET_TIME_absolute_hton (now),
+        .end_date = GNUNET_TIME_absolute_hton (now),
         .auditor_pub = auditor_pub,
       };
 
-      GNUNET_CRYPTO_hash (auditor_url,
-                          strlen (auditor_url) + 1,
-                          &kv.h_auditor_url);
       /* Finally sign ... */
       GNUNET_CRYPTO_eddsa_sign (&master_priv.eddsa_priv,
                                 &kv,
                                 &master_sig.eddsa_signature);
     }
   }
-  if (GNUNET_OK !=
-      GNUNET_CONFIGURATION_get_value_filename (is->cfg,
-                                               "auditor",
-                                               "BASE_URL",
-                                               &auditor_url))
-  {
-    GNUNET_log_config_missing (GNUNET_ERROR_TYPE_ERROR,
-                               "auditor",
-                               "BASE_URL");
-    TALER_TESTING_interpreter_next (ds->is);
-    return;
-  }
   if (GNUNET_OK !=
       GNUNET_CONFIGURATION_get_value_string (is->cfg,
                                              "exchange",
@@ -238,21 +222,18 @@ auditor_add_run (void *cls,
     GNUNET_log_config_missing (GNUNET_ERROR_TYPE_ERROR,
                                "exchange",
                                "BASE_URL");
-    GNUNET_free (auditor_url);
     TALER_TESTING_interpreter_next (ds->is);
     return;
   }
-  ds->dh = TALER_EXCHANGE_management_enable_auditor (
+  ds->dh = TALER_EXCHANGE_management_disable_auditor (
     is->ctx,
     exchange_url,
     &auditor_pub,
-    auditor_url,
     now,
     &master_sig,
-    &auditor_add_cb,
+    &auditor_del_cb,
     ds);
   GNUNET_free (exchange_url);
-  GNUNET_free (auditor_url);
   if (NULL == ds->dh)
   {
     GNUNET_break (0);
@@ -263,17 +244,17 @@ auditor_add_run (void *cls,
 
 
 /**
  * Free the state of a "auditor_add" CMD, and possibly cancel a
  * pending operation thereof.
  *
  * @param cls closure, must be a `struct AuditorAddState`.
  * @param cmd the command which is being cleaned up.
  */
 static void
-auditor_add_cleanup (void *cls,
+auditor_del_cleanup (void *cls,
                      const struct TALER_TESTING_Command *cmd)
 {
-  struct AuditorAddState *ds = cls;
+  struct AuditorDelState *ds = cls;
 
   if (NULL != ds->dh)
   {
@@ -281,7 +262,7 @@ auditor_add_cleanup (void *cls,
                 "Command %u (%s) did not complete\n",
                 ds->is->ip,
                 cmd->label);
-    TALER_EXCHANGE_management_enable_auditor_cancel (ds->dh);
+    TALER_EXCHANGE_management_disable_auditor_cancel (ds->dh);
     ds->dh = NULL;
   }
   GNUNET_free (ds);
@@ -289,7 +270,7 @@ auditor_add_cleanup (void *cls,
 
 
 /**
  * Offer internal data from a "auditor_add" CMD, to other commands.
  *
  * @param cls closure.
  * @param[out] ret result.
@@ -299,7 +280,7 @@ auditor_add_cleanup (void *cls,
  * @return #GNUNET_OK on success.
  */
 static int
-auditor_add_traits (void *cls,
+auditor_del_traits (void *cls,
                     const void **ret,
                     const char *trait,
                     unsigned int index)
@@ -309,22 +290,22 @@ auditor_add_traits (void *cls,
 
 
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_auditor_add (const char *label,
+TALER_TESTING_cmd_auditor_del (const char *label,
                                unsigned int expected_http_status,
                                bool bad_sig)
 {
-  struct AuditorAddState *ds;
+  struct AuditorDelState *ds;
 
-  ds = GNUNET_new (struct AuditorAddState);
+  ds = GNUNET_new (struct AuditorDelState);
   ds->expected_response_code = expected_http_status;
   ds->bad_sig = bad_sig;
   {
     struct TALER_TESTING_Command cmd = {
       .cls = ds,
       .label = label,
-      .run = &auditor_add_run,
-      .cleanup = &auditor_add_cleanup,
-      .traits = &auditor_add_traits
+      .run = &auditor_del_run,
+      .cleanup = &auditor_del_cleanup,
+      .traits = &auditor_del_traits
     };
 
     return cmd;
@@ -332,4 +313,4 @@ TALER_TESTING_cmd_auditor_add (const char *label,
 }
 
 
-/* end of testing_api_cmd_auditor_add.c */
+/* end of testing_api_cmd_auditor_del.c */
@@ -17,9 +17,9 @@
 */
 /**
- * @file testing/testing_api_cmd_auditor_add.c
- * @brief command for testing /auditor_add.
- * @author Marcello Stanisci
+ * @file testing/testing_api_cmd_auditor_del.c
+ * @brief command for testing /management/auditor/disable.
+ * @author Christian Grothoff
  */
 #include "platform.h"
@@ -30,15 +30,15 @@
 
 /**
- * State for a "auditor_add" CMD.
+ * State for a "auditor_del" CMD.
  */
@@ -263,17 +244,17 @@ auditor_add_run (void *cls,
 
 /**
- * Free the state of a "auditor_add" CMD, and possibly cancel a
+ * Free the state of a "auditor_del" CMD, and possibly cancel a
  * pending operation thereof.
  *
@@ -263,17 +244,17 @@ auditor_add_run (void *cls,
  * pending operation thereof.
  *
- * @param cls closure, must be a `struct AuditorAddState`.
+ * @param cls closure, must be a `struct AuditorDelState`.
  * @param cmd the command which is being cleaned up.
  */
@@ -289,7 +270,7 @@ auditor_add_cleanup (void *cls,
 
 /**
- * Offer internal data from a "auditor_add" CMD, to other commands.
+ * Offer internal data from a "auditor_del" CMD, to other commands.
  *
  * @param cls closure.

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]